==> sso-api-2.3.53-sources.jar: cn/com/duiba/sso/api/web/controller/SsoMobileController.java <==
package cn.com.duiba.sso.api.web.controller;

import cn.com.duiba.sso.api.constants.SsoProperties;
import cn.com.duiba.sso.api.remoteservice.RemoteSSOService;
import cn.com.duiba.sso.api.tool.CookieUtil;
import cn.com.duiba.sso.api.tool.RequestTool;
import cn.com.duiba.sso.api.tool.SystemInfo;
import cn.com.duiba.sso.api.web.interceptor.annotation.CanAccess;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.StringEscapeUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Optional;

@Controller
@RequestMapping("/mobile/sso")
public class SsoMobileController {

    private static Logger logger = LoggerFactory.getLogger(SsoMobileController.class);

    @Autowired
    private RemoteSSOService remoteSSOService;
    @Autowired
    private SsoProperties properties;

    @CanAccess
    @RequestMapping("/ssoIndex")
    public void ssoIndex(@RequestParam Long ssoStamp, @RequestParam(required = false) String redirect) throws IOException {

        HttpServletResponse response = RequestTool.getResponse();
        try{

            redirect = fixRedirect(redirect);

            Long systemId = SystemInfo.getThisSystemId();
            String ticket = remoteSSOService.findTicketByStamp(systemId,ssoStamp);

            CookieUtil.setCookie(CookieUtil.LOGIN_COOKIE_NAME,ticket);

            String url = Optional.ofNullable(redirect).orElse(properties.getMobileDefaultRedirectUrl());

            response.sendRedirect(url);
        }catch (Exception e){
            logger.error("跳转登录失败",e);
            response.getWriter().write("跳转登录失败");
        }
    }

    private String fixRedirect(String url){
        if(StringUtils.isBlank(url)){
            return url;
        }
        return StringEscapeUtils.unescapeHtml3(url);
    }
}

==> sso-api-2.3.78-sources.jar: cn/com/duiba/sso/api/web/controller/SsoMobileController.java <==
package cn.com.duiba.sso.api.web.controller;

import cn.com.duiba.sso.api.constants.SsoProperties;
import cn.com.duiba.sso.api.domain.dto.AdminDto;
import cn.com.duiba.sso.api.remoteservice.RemoteSSOService;
import cn.com.duiba.sso.api.tool.CookieUtil;
import cn.com.duiba.sso.api.tool.RequestTool;
import cn.com.duiba.sso.api.tool.SystemInfo;
import cn.com.duiba.sso.api.web.interceptor.annotation.CanAccess;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.StringEscapeUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Optional;

@Controller
@RequestMapping("/mobile/sso")
public class SsoMobileController {

    private static Logger logger = LoggerFactory.getLogger(SsoMobileController.class);

    @Autowired
    private RemoteSSOService remoteSSOService;
    @Autowired
    private SsoProperties properties;

    @CanAccess
    @RequestMapping("/ssoIndex")
    public void ssoIndex(@RequestParam Long ssoStamp, @RequestParam(required = false) String redirect) throws IOException {

        HttpServletResponse response = RequestTool.getResponse();
        try{

            redirect = fixRedirect(redirect);

            Long systemId = SystemInfo.getThisSystemId();
            String ticket = remoteSSOService.findTicketByStamp(systemId,ssoStamp);
            AdminDto admin = remoteSSOService.verifyTicketAndGetAdmin(ticket);
            CookieUtil.setCookie(CookieUtil.LOGIN_COOKIE_NAME,ticket,admin.getLoginTimeout());

            String url = Optional.ofNullable(redirect).orElse(properties.getMobileDefaultRedirectUrl());

            response.sendRedirect(url);
        }catch (Exception e){
            logger.error("跳转登录失败",e);
            response.getWriter().write("跳转登录失败");
        }
    }

    private String fixRedirect(String url){
        if(StringUtils.isBlank(url)){
            return url;
        }
        return StringEscapeUtils.unescapeHtml3(url);
    }
}
